import { ContentView } from "tns-core-modules/ui/content-view";
import { EventData } from "tns-core-modules/data/observable";
export declare enum ARDebugLevel {
    NONE,
    WORLD_ORIGIN,
    FEATURE_POINTS,
    PHYSICS_SHAPES,
}
export interface ARNode {
    id: string;
    position: ARPosition;
    ios?: any;
    android?: any;
    remove(): void;
}
export interface ARAddOptions {
    position: ARPosition;
    mass?: number;
    onTap?: (model: ARNode) => void;
    onLongPress?: (model: ARNode) => void;
}
export interface ARAddGeometryOptions extends ARAddOptions {
    material?: string;
}
export interface ARAddModelOptions extends ARAddOptions {
    name: string;
    childNodeName?: string;
    scale: number | ARPosition;
}
export interface ARAddBoxOptions extends ARAddGeometryOptions {
    scale: number | ARPosition;
}
export interface ARAddSphereOptions extends ARAddGeometryOptions {
    radius: number;
}
export interface ARAddTubeOptions extends ARAddGeometryOptions {
    innerRadius: number;
    outerRadius: number;
    height: number;
    radialSegmentCount?: number;
    heightSegmentCount?: number;
}
export interface ARPlaneTappedEventData extends EventData {
    position: ARPosition;
}
export declare class ARPosition {
    x: number;
    y: number;
    z: number;
    constructor(x: number, y: number, z: number);
}
export declare abstract class ARBase extends ContentView {
    static arLoadedEvent: string;
    static planeDetectedEvent: string;
    static planeTappedEvent: string;
    static isSupported(): boolean;
    abstract reset(): void;
    abstract addModel(options: ARAddModelOptions): Promise<ARNode>;
    abstract addBox(options: ARAddBoxOptions): Promise<ARNode>;
    abstract addSphere(options: ARAddSphereOptions): Promise<ARNode>;
    abstract addTube(options: ARAddTubeOptions): Promise<ARNode>;
    abstract togglePlaneDetection(on: boolean): void;
    abstract toggleStatistics(on: boolean): void;
    abstract togglePlaneVisibility(on: boolean): void;
    abstract setDebugLevel(to: ARDebugLevel): void;
}
